@@ -58,7 +58,8 @@ class Subscriber
 
 		/* ugly hack to circumvent the missing constructor overloading of PHP5 */
 		$this->nren = $nren; /* NREN-object */
-		$this->idp_name = Input::sanitizeIdPName($idp_name);
+		$this->idp_name = htmlentities($idp_name);
+
 		if (isset($dn_name) && isset($org_state)) {
 			$this->setOrgName($dn_name);
 			$this->setState($org_state);
@@ -472,9 +473,13 @@ class Subscriber
 	 * @return	String|null
 	 * @access	public
 	 */
-	public function getComment()
+	public function getComment($br2nl = null)
 	{
 		if (isset($this->comment)) {
+            //change html <br /> tags to new lines for textarea input
+            if($br2nl) {
+                return str_replace('<br />', "\n", $this->comment);
+            }
 			return $this->comment;
 		}
 		return null;
