@@ -104,8 +104,7 @@ abstract class Confusa_Auth
 
 			/* Now that we have the NREN-map, reiterate getMap() in
 			 * case we can find the subscriber-map. */
-			$subscriberIdPName = Input::sanitizeIdPName($attributes[$map['epodn']][0]);
-			$this->person->setSubscriber(new Subscriber($subscriberIdPName,
+			$this->person->setSubscriber(new Subscriber($attributes[$map['epodn']][0],
 								    $this->person->getNREN()));
 			$new_map = $this->person->getMap();
 			if ($this->mapSanityCheck($new_map)) {
@@ -118,19 +117,7 @@ abstract class Confusa_Auth
 			}
 			if(!is_null($map['cn'])) {
 				if (array_key_exists($map['cn'], $attributes)) {
-					$cn = Input::sanitizePersonName($attributes[$map['cn']][0]);
-					if ($cn !== $attributes[$map['cn']][0]) {
-						/* need to keep track of issued warning,
-						 * some pages call ecoratePerson twice */
-						static $cn_changed_seen = false;
-						if (!$cn_changed_seen) {
-							$cn_changed_seen = true;
-							$msg = "Your CN contains characters deemed illegal in the certificate <br />".
-								"Original: " . htmlentities($attributes[$map['cn']][0]) . " <br />" .
-								"Current: $cn";
-							Framework::error_output($msg);
-						}
-					}
+					$cn = mysql_real_escape_string($attributes[$map['cn']][0]);
 					$this->person->setName($cnPrefix . $cn);
 				}
 			} /* end map has cn */
@@ -338,5 +325,13 @@ abstract class Confusa_Auth
 	 * on their own reAuthentication needs.
 	 */
 	public abstract function reAuthenticate();
+
+	/**
+	 * Get the path to the discovery-site for the given auth-module.
+	 *
+	 * This is where you normally see a (scoped) list of available
+	 * authentication sources.
+	 */
+	public abstract function getDiscoPath();
 } /* end class Confusa_Auth */
 ?>
