@@ -232,6 +232,12 @@ class Framework {
 		 * Header set X-Frame-Options "DENY"
 		 */
 		header('X-Frame-Options: DENY');
+		/*
+		 * Strict-Transport-Security (RFC 6797)
+		 * Once page has been accessed over HTTPS and this header was present,
+		 * confirmant browsers will force subsequent requests over HTTPS aswell.
+		 */
+		header('Strict-Transport-Security: max-age=31536000');
 
 		/* Set tpl object to content page */
 		$this->contentPage->setTpl($this->tpl);
@@ -248,7 +254,16 @@ class Framework {
 			Framework::error_output($msg);
 			$this->renderError = true;
 		} catch (MapNotFoundException $mnfe) {
-			Framework::error_output($this->contentPage->translateMessageTag('fw_error_map_notfound'));
+			$msg = $this->contentPage->translateMessageTag('fw_error_map_notfound');
+
+			/* if user is admin */
+			if ($this->person->isNRENAdmin()) {
+				$msg .= "<br /><br />";
+				$msg .= "<a href=\"attributes.php?mode=admin&anticsrf=".Framework::getAntiCSRF()."\">";
+				$msg .= $this->contentPage->translateMessageTag('fw_error_map_updatemap');
+				$msg .= "</>\n";
+			}
+			Framework::error_output($msg);
 			$this->renderError = true;
 		} catch (ConfusaGenException $cge) {
 			Framework::error_output($this->contentPage->translateMessageTag('fw_error_auth') .
