@@ -68,21 +68,6 @@ class Input
 		return preg_replace('/[^0-9]+[:][^a-f0-9]+/i', '', $token);
 	}
 
-	/**
-	 * Sanitize Confusa's internal representation of a subscriber-name. This
-	 * equals the value sent in the attribute identifying the subscriber
-	 * (eduPersonOrgDN, schacHomeOrganization).
-	 * No validation, just removal of "bad" characters
-	 *
-	 * @param $input string The unsanitized subscriber-db-name
-	 * @return string The sanitized subscriber-IdP-name
-	 */
-	static function sanitizeIdPName($input)
-	{
-		$output = preg_replace('/[^a-z0-9_=,:\/\s\.\-@]/i','', $input);
-		return $output;
-	}
-
 	/**
 	 * Sanitize a numeric ID (like the primary key in a DB)
 	 * @param $input string ID input
@@ -322,7 +307,11 @@ class Input
 		 * text. Since it is undesired to directly insert newlines into the DB
 		 * convert them to <br /> tags. Direct HTML insertion has been dealt
 		 * with using htmlentities*/
-		$input = strtr(strip_tags($input), array("\n" => '<br />', "\r\n" =>'<br />'));
+
+        /* allow <br /> tags with strip_tags, otherwise the <br />'s you insert
+         * here will be stripped the next time the text is sanitized!
+         */
+		$input = strtr(strip_tags($input, '<br>'), array("\n" => '<br />', "\r\n" =>'<br />'));
 
 		/* The following is a *HACK*
 		 * However, since we want to use the mysql_real_escape_string,
