@@ -1,17 +1,5 @@
 <?php
 
-class NREN
-{
-	private $name;
-	private $country;
-	function __construct($n = "Mock NREN", $c = "NO")
-	{
-		$this->name = $n;
-		$this->country = $c;
-	}
-	function getName() { return $this->name; }
-	function getCountry() { return $this->country; }
-}
 class Subscriber
 {
 	private $idp;
